@@ -35,7 +35,7 @@
 #include <QDBusReply>
 #include <QStandardPaths>
 
-EXPORT_KONTACT_PLUGIN(KAddressBookPlugin, kaddressbook)
+EXPORT_KONTACT_PLUGIN_WITH_JSON(KAddressBookPlugin, "kaddressbookplugin.json")
 
 KAddressBookPlugin::KAddressBookPlugin(KontactInterface::Core *core, const QVariantList &)
     : KontactInterface::Plugin(core, core, "kaddressbook")
@@ -78,7 +78,7 @@ KAddressBookPlugin::~KAddressBookPlugin()
 
 void KAddressBookPlugin::slotNewContact()
 {
-    KParts::ReadOnlyPart *part = createPart();
+    KParts::Part *part = createPart();
     if (!part) {
         return;
     }
@@ -93,7 +93,7 @@ void KAddressBookPlugin::slotNewContact()
 
 void KAddressBookPlugin::slotNewContactGroup()
 {
-    KParts::ReadOnlyPart *part = createPart();
+    KParts::Part *part = createPart();
     if (!part) {
         return;
     }
@@ -106,16 +106,16 @@ void KAddressBookPlugin::slotNewContactGroup()
     QMetaObject::invokeMethod(part, "newGroup");
 }
 
-KParts::ReadOnlyPart *KAddressBookPlugin::createPart()
+KParts::Part *KAddressBookPlugin::createPart()
 {
-    KParts::ReadOnlyPart *part = loadPart();
+    KParts::Part *part = loadPart();
     if (!part) {
         return nullptr;
     }
 
     // disable the Ctrl+N shortcut, as it is used by Kontact already
     if (part->action("akonadi_contact_create")) {
-        QAction *newAction = qobject_cast<QAction *>(part->action("akonadi_contact_create"));
+        QAction *newAction = part->action("akonadi_contact_create");
         if (newAction) {
             newAction->setShortcut(QKeySequence());
         }
@@ -143,7 +143,7 @@ QStringList KAddressBookPlugin::invisibleToolbarActions() const
 
 void KAddressBookPlugin::shortcutChanged()
 {
-    KParts::ReadOnlyPart *localPart = part();
+    KParts::Part *localPart = part();
     if (localPart) {
         if (localPart->metaObject()->indexOfMethod("updateQuickSearchText()") == -1) {
             qCWarning(KADDRESSBOOKPLUGIN_LOG) << "KAddressBook part is missing slot updateQuickSearchText()";
@@ -164,6 +164,7 @@ int KAddressBookUniqueAppHandler::activate(const QStringList &arguments, const Q
     (void)plugin()->part();
     org::kde::kaddressbook kaddressbook(QStringLiteral("org.kde.kaddressbook"), QStringLiteral("/KAddressBook"), QDBusConnection::sessionBus());
     QDBusReply<bool> reply = kaddressbook.handleCommandLine(arguments);
+    Q_UNUSED(reply);
 
     return KontactInterface::UniqueAppHandler::activate(arguments, workingDir);
 }
