@@ -32,11 +32,11 @@
 #include "kaddressbook_options.h"
 #include "manageshowcollectionproperties.h"
 
-#include "KaddressbookGrantlee/GrantleeContactFormatter"
-#include "KaddressbookGrantlee/GrantleeContactGroupFormatter"
-#include "grantleetheme/grantleethememanager.h"
+#include <KaddressbookGrantlee/GrantleeContactFormatter>
+#include <KaddressbookGrantlee/GrantleeContactGroupFormatter>
+#include <GrantleeTheme/GrantleeThemeManager>
 
-#include "Libkdepim/UiStateSaver"
+#include <Libkdepim/UiStateSaver>
 
 #include <PimCommonAkonadi/ImapAclAttribute>
 #include <PimCommonAkonadi/MailUtil>
@@ -54,8 +54,8 @@
 #include <AkonadiSearch/Debug/akonadisearchdebugdialog.h>
 #include <KContacts/Addressee>
 #include <QPointer>
-#include "PimCommonAkonadi/ManageServerSideSubscriptionJob"
-#include "PimCommon/PimUtil"
+#include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
+#include <PimCommon/PimUtil>
 #include <KAddressBookImportExport/KAddressBookImportExportPluginManager>
 #include <KAddressBookImportExport/KAddressBookImportExportPlugin>
 #include <KAddressBookImportExport/KAddressBookImportExportPluginInterface>
@@ -402,6 +402,9 @@ void MainWidget::handleCommandLine(const QStringList &arguments)
         }
     } else if (parser.isSet(QStringLiteral("newcontact"))) {
         newContact();
+    } else if (parser.isSet(QStringLiteral("view"))) {
+        const auto url = QUrl{parser.value(QStringLiteral("view"))};
+        mPendingSelection = Akonadi::Item::fromUrl(url);
     }
 }
 
@@ -472,8 +475,14 @@ void MainWidget::restoreState()
         saver->setView(mItemView);
         saver->setSelectionModel(mItemView->selectionModel());
 
-        const KConfigGroup group(Settings::self()->config(), "ItemViewState");
-        saver->restoreState(group);
+        if (mPendingSelection.isValid()) {
+            saver->selectItems({mPendingSelection});
+            saver->setCurrentItem(mPendingSelection);
+            mPendingSelection = {};
+        } else {
+            const KConfigGroup group(Settings::self()->config(), "ItemViewState");
+            saver->restoreState(group);
+        }
     }
 }
 
