@@ -3,7 +3,7 @@
   Copyright (c) 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
                      Tobias Koenig <tokoe@kde.org>
 
-  Copyright (c) 2009-2019 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 
 class QLabel;
 class QPixmap;
-class KComboBox;
+class QComboBox;
 
 class StylePage : public QWidget
 {
@@ -99,9 +99,9 @@ private:
     void initGUI();
     void initFieldCombo();
 
-    KComboBox *mFieldCombo = nullptr;
-    KComboBox *mSortTypeCombo = nullptr;
-    KComboBox *mStyleCombo = nullptr;
+    QComboBox *mFieldCombo = nullptr;
+    QComboBox *mSortTypeCombo = nullptr;
+    QComboBox *mStyleCombo = nullptr;
     QLabel *mPreview = nullptr;
 
     KAddressBookImportExport::KAddressBookImportExportContactFields::Fields mFields;
